@@ -27,10 +27,31 @@ class File:
         if os.path.exists(url) is False:
             print 'File not exists, %s. Please check.' % url
             return None
+        to_string = kwargs.get('to_string')
         if file_type in ['xlsx', 'xls']:
             data = xlrd.open_workbook(url)
-            return data.sheet_by_name(sheet_name)
-        to_string = kwargs.get('to_string')
+            table = data.sheet_by_name(sheet_name)
+            items = []
+            ths = table.row_values(0)
+            strings = '\t'.join(ths)
+            items1 = [ths]
+            nrow = table.nrows
+            for i in range(1, nrow):
+                item1 = []
+                item = []
+                for j in range(0, len(ths)):
+                    cell = table.cell_value(i, j)
+                    item[ths[j]] = cell
+                    item1[j] = cell
+                if to_string:
+                    strings += '\n%s' % ('\t'.join(item1))
+                items.append(item)
+                items1.append(item1)
+            if to_string:
+                return strings.strip('\n')
+            if to_json:
+                return items
+            return items1
         f = open(url, read_type)
         text = f.read()
         f.close()
